# getpkg - Simple Package Manager

getpkg is a command-line package manager that makes it easy to install and manage developer tools. Tools are automatically installed to your home directory and added to your PATH.

## Quick Start

Install getpkg with one command:

```bash
curl https://getbin.xyz/getpkg-install | bash
```

After installation, restart your shell or run:
```bash
source ~/.bashrc
```

## Basic Commands

### Install Tools
```bash
getpkg install <tool_name>    # Install a tool
getpkg list                   # See all available tools
getpkg update                 # Update all installed tools
```

### Manage Tools
```bash
getpkg uninstall <tool_name>  # Remove a tool
getpkg version                # Check getpkg version
getpkg help                   # Show all commands
```

## Popular Tools

Install these useful developer tools:

```bash
getpkg install bb64           # Bash-compatible base64 encoder/decoder
getpkg install dehydrate      # Convert files to C++ source code
getpkg install whatsdirty     # Check git repository status
getpkg install sos            # Simple object storage client
getpkg install gp             # Git push utility
```

## How It Works

When you install a tool:
1. Downloads from getpkg.xyz
2. Installs to `~/.getpkg/<tool_name>/`
3. Creates shortcuts in `~/.local/bin/getpkg/`
4. Adds to your PATH automatically
5. Enables bash completion

## File Locations

- **Installed tools**: `~/.getpkg/<tool_name>/`
- **Shortcuts**: `~/.local/bin/getpkg/` (in your PATH)
- **Settings**: `~/.config/getpkg/`

## Architecture Support

getpkg automatically downloads the right version for your system:
- Intel/AMD 64-bit (`x86_64`)
- ARM 64-bit (`aarch64`)
- Universal (works everywhere)

## Troubleshooting

**Tool not found after install?**
```bash
source ~/.bashrc
```

**Permission errors?**
getpkg installs to your home directory - no root access needed.

**Network issues?**
Check your internet connection to `getpkg.xyz`.

## Need Help?

```bash
getpkg help                   # Show detailed help
getpkg list                   # See what's available
```